
#ifndef FST_INCLUDE
#define FST_INCLUDE
/*------------------------------------------------------
 Maximum likelihood estimation 
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm                            
 -------------------------------------------------------                        
 F S T   R O U T I N E S 

 calculates FST
 

 Peter Beerli 1996, Seattle
 beerli@genetics.washington.edu
 $Id: fst.h,v 1.2 2000/10/13 22:56:41 beerli Exp $
-------------------------------------------------------*/
extern void fst_type (char type);
extern void calc_fst (world_fmt * world, data_fmt *data);

#endif /* FST_INCLUDE */
